/**
 * src/qchaco/C64File.cpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

/* class declaration */
#include "C64File.hpp"

/* system headers */

/* Qt headers */
#include <QFile>

/* local library headers */

/* local headers */


C64File::C64File( const QString &fileName )
: mIsValid( false )
, mStartAddress( 0 )
, mEndAddress( 0 )
, mFileData()
{
   QFile file( fileName );
   file.open( QIODevice::ReadOnly );
   mFileData = file.readAll();
   file.close();

   if( mFileData.startsWith("C64File") &&
       (mFileData.size() > 29) )
   {
      mFileData = mFileData.mid(26);
   }

   if( (mFileData.size() > 2) &&
       (mFileData.size() < 0x10000) )
   {
      mIsValid = true;
      mStartAddress = mFileData.at( 0 ) | (mFileData.at( 1 ) << 8);
      mEndAddress = mFileData.size() - 2 + mStartAddress;
      mFileData = mFileData.mid( 2 );
   }
}


C64File::~C64File()
{
}


bool C64File::isValid()
{
   return mIsValid;
}


unsigned short C64File::startAddress()
{
   return mStartAddress;
}


unsigned short C64File::endAddress()
{
   return mEndAddress;
}


const QByteArray &C64File::fileData()
{
   return mFileData;
}
