/**
 * src/qchaco/ChacoCmd.hpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

#ifndef CHACOCMD_HPP
#define CHACOCMD_HPP CHACOCMD_HPP

/* base class */
#include <QThread>

/* system headers */

/* Qt headers */
#include <QProcess>

/* local library headers */

/* local headers */

/* forward declaration of Qt classes */
class QByteArray;
class QProcess;

/* forward declaration of local classes */


class ChacoCmd : public QThread
{
Q_OBJECT

public:
   ChacoCmd( QObject *parent = 0 );
   virtual ~ChacoCmd();

   /* worker thread main loop */
   void run();

public slots:
   /* reset error state */
   void resetError();
   /* set file path */
   void setFilePath( const QString &name );
   /* get file path */
   const QString &filePath();
   /* start a core */
   void startCore( int slot );
   /* flash the chameleon */
   void flashRbf( int slot, const QString &coreName,
                  const QByteArray &romData );
   /* upload data to ram */
   void upload( unsigned long addr, const QByteArray &data );
   /* upload data to ram */
   void upload( unsigned long addr, const QString &fileName );
   /* download data from ram */
   void download( unsigned long addr, unsigned long size,
                  QObject *target, const QString &method );
   /* handle replies from chacocmd */
   void handleReadyRead();

signals:
   /* output messages for logging */
   void output( const QString &text );
   /* set error number */
   void error( int retval );
   /* communicate if chacocmd is running */
   void active( bool isActive );

private:
   ChacoCmd( const ChacoCmd &other );
   ChacoCmd &operator=( const ChacoCmd &other );

   /* run one command with chacocmd */
   void sendCmd( const QStringList &args, int dataSize = 0 );

   bool        mErrored;
   QProcess    *mpProcess;
   QString     mFilePath;
};

#endif
