/**
 * src/qchaco/ConfigWidget.cpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

/* class declaration */
#include "ConfigWidget.hpp"

/* system headers */

/* Qt headers */
#include <QDragEnterEvent>
#include <QDropEvent>
#include <QFormLayout>
#include <QSettings>
#include <QSpinBox>
#include <QUrl>

/* local library headers */

/* local headers */
#include "ChacoCmd.hpp"
#include "FileNameEdit.hpp"


ConfigWidget::ConfigWidget( ChacoCmd *chacoCmd, QWidget *parent )
: QWidget( parent )
, mpChacoCmd( chacoCmd )
, mpChacoCmdFileName( new FileNameEdit( this ) )
, mpHistorySize( new QSpinBox( this ) )
{
   QSettings settings;
   mpChacoCmdFileName->setRegistryKey( "chacocmd" );
   mpHistorySize->setRange( 0, 999 );
   mpHistorySize->setAlignment( Qt::AlignRight );
   QString fileName( settings.value("ChacoCmd").toString() );
   mpChacoCmdFileName->setFileName( fileName );
   mpChacoCmd->setFilePath( fileName );
   setAcceptDrops( true );

   QFormLayout *layout = new QFormLayout( this );
   layout->setContentsMargins( 3, 3, 3, 3 );
   layout->setSpacing( 1 );
   QBoxLayout *historyLayout = new QHBoxLayout;
   historyLayout->addWidget( mpHistorySize );
   historyLayout->addStretch( 1 );

   layout->addRow( tr("ChacoCmd:"),     mpChacoCmdFileName );
   layout->addRow( tr("History Size:"), historyLayout );

   setLayout( layout );

   connect( mpChacoCmdFileName, SIGNAL(fileNameChanged(QString)),
            this, SLOT(fileNameChanged(QString)) );
   connect( mpHistorySize, SIGNAL(valueChanged(int)),
            this, SLOT(setHistorySize(int)) );
   mpHistorySize->setValue( settings.value( "HistorySize", 50 ).toInt() );
}


ConfigWidget::~ConfigWidget()
{
   mpChacoCmdFileName->addCurrentEntry();
}


void ConfigWidget::dragEnterEvent( QDragEnterEvent *event )
{
   if( event->mimeData()->hasFormat( "text/uri-list" ) )
   {
      event->acceptProposedAction();
   }
}


void ConfigWidget::dropEvent( QDropEvent *event )
{
   QList<QUrl> urls( event->mimeData()->urls() );
   if( urls.isEmpty() )
   {
      return;
   }
   QString fileName( urls.first().toLocalFile() );
   if( fileName.isEmpty() )
   {
      return;
   }
   mpChacoCmdFileName->setFileName( fileName );
}


void ConfigWidget::fileNameChanged( const QString &path )
{
   mpChacoCmd->setFilePath( path );
}


void ConfigWidget::setHistorySize( int size )
{
   FileNameEdit::setHistorySize( size );
   QSettings().setValue( "HistorySize", mpHistorySize->value() );
}
