/**
 * src/qchaco/D64File.hpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

#ifndef D64FILE_HPP
#define D64FILE_HPP D64FILE_HPP

/* base class */

/* system headers */
#include <stdio.h>

/* Qt headers */
#include <QByteArray>
#include <QList>

/* local library headers */

/* local headers */
extern "C" {
#include "gcr.h"
}

/* forward declaration of Qt classes */
class QString;

/* forward declaration of local classes */
class Class;


class D64File
{
public:
   D64File( const QString &fileName );
   D64File( int tracks );
   virtual ~D64File();

   /* do we have valid data? */
   bool isValid();
   /* generate empty GCR data */
   void formatGcr( char id1 = ' ', char id2 = ' ' );
   /* convert the D64 image to GCR data */
   void convertToGcr();
   /* convert GCR data back to the D64 image */
   void convertFromGcr();
   /* get a copy of GCR data */
   QByteArray getGcrData();
   /* write data to GCR buffer */
   bool setGcrData( const QByteArray &data );
   /* get a copy of cooked data */
   QByteArray getD64Data();

private:
   D64File( const D64File &other );
   D64File &operator=( const D64File &other );

   enum convertTarget { ToTrackNumber, ToSectorNumber,
                        ToSectorsPerTrack, ToGcrSizeOfTrack,
                        ToSectorOffset };

   /* convert an absolute block number to track number */
   static int convertBlockNumberTo( int block, enum convertTarget to );

   bool                 mIsValid;
   bool                 mZeroFilledBlocks;
   bool                 m40Tracks;
   gcr_t                *mpGcrData;
   QByteArray           mFileData;
};

#endif
