/**
 * src/qchaco/D64Widget.hpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

#ifndef D64WIDGET_HPP
#define D64WIDGET_HPP D64WIDGET_HPP

/* base class */
#include <QWidget>

/* system headers */

/* Qt headers */

/* local library headers */

/* local headers */

/* forward declaration of Qt classes */
class QComboBox;
class QLabel;
class QPushButton;

/* forward declaration of local classes */
class BaseSpinBox;
class FileNameEdit;
class HexEdit;
class HistoryList;


class D64Widget : public QWidget
{
Q_OBJECT

public:
   D64Widget( QWidget *parent = 0 );
   virtual ~D64Widget();

public slots:
   /* upload the current file using chacocmd */
   void upload();
   /* download to a file using chacocmd */
   void download();
   /* load the disc-id from the image */
   void loadId( const QString &fileName );
   /* deactivate the upload button */
   void deactivate( bool deactivated );
   /* handle downloaded data */
   void saveData( const QByteArray &data );

signals:
   /* initiate chacocmd communication */
   void requestTransferStart();
   /* send data for upload */
   void requestUpload( unsigned long addr, const QByteArray &data );
   /* send data for download */
   void requestDownload( unsigned long addr, unsigned long size,
                         QObject *target, const QString &method );

protected:
   /* handle drag'n'drop part one */
   void dragEnterEvent( QDragEnterEvent *event );
   /* handle drag'n'drop part two */
   void dropEvent( QDropEvent *event );

private:
   D64Widget( const D64Widget &other );
   D64Widget &operator=( const D64Widget &other );

   unsigned long slotToAddr();

   FileNameEdit      *mpFileName;
   QComboBox         *mpDrive;
   HexEdit           *mpId1;
   HexEdit           *mpId2;
   QPushButton       *mpUpload;
   QPushButton       *mpDownload;
#if 0
   QLabel            *mpInfo;
#endif
};

#endif
