/**
 * src/qchaco/FileNameEdit.hpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

#ifndef FILENAMEEDIT_HPP
#define FILENAMEEDIT_HPP FILENAMEEDIT_HPP

/* base class */
#include <QFrame>

/* system headers */

/* Qt headers */

/* local library headers */

/* local headers */

/* forward declaration of Qt classes */
class QComboBox;
class QDragEnterEvent;
class QDropEvent;
class QPushButton;

/* forward declaration of local classes */


class FileNameEdit : public QFrame
{
Q_OBJECT

public:
   FileNameEdit( QWidget *parent = 0 );
   virtual ~FileNameEdit();

   Q_PROPERTY( QString fileName
               READ fileName
               WRITE setFileName )
   /* get the filename */
   QString fileName() const;

   Q_PROPERTY( QString registryKey
               READ registryKey
               WRITE setRegistryKey )
   /* get the registry key where to history is stored */
   QString registryKey() const;
   /* set the registry key where to store history */
   void setRegistryKey( const QString &key );

   /* set the history size for all instances */
   static void setHistorySize( int size );

public slots:
   /* start the file requester */
   void requester();
   /* check if the filename is valid */
   void checkFileName();
   /* set the filename */
   void setFileName( const QString &name );
   /* add the current entry to history */
   void addCurrentEntry();

signals:
   /* notify that the filename has changed */
   void fileNameChanged( const QString &fileName );

protected:
   /* handle drag'n'drop part one */
   void dragEnterEvent( QDragEnterEvent *event );
   /* handle drag'n'drop part two */
   void dropEvent( QDropEvent *event );

private:
   FileNameEdit( const FileNameEdit &other );
   FileNameEdit &operator=( const FileNameEdit &other );

   /* read history from registry */
   void readFromRegistry();
   /* write history to registry */
   void writeToRegistry();

   static int     cMaxEntries;

   QComboBox      *mpEdit;
   QPushButton    *mpPushButton;

   QString        mRegistryKey;
};

#endif
