/**
 * src/qchaco/FlashAddonWidget.cpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

/* class declaration */
#include "FlashAddonWidget.hpp"

/* system headers */

/* Qt headers */
#include <QtGui>

/* local library headers */

/* local headers */
#include "FileNameEdit.hpp"


/*
 * ROM layout
 * 000000-007fff - bootloader
 * 008000-009fff - mmc64 bios
 * 00a000-00bfff - basic
 * 00d000-00dfff - character rom
 * 00e000-00ffff - kernal
 * 010000-01ffff - final cartridge iii
 * 020000-02ffff - retro replay
 * 030000-03ffff - chameleon system menu
 * 048000-087fff - **empty**
 * 088000-08bfff - 1541 dos
 * 08c000-08ffff - 1541 dos
 * 090000-097fff - **empty**
 * 098000-09bfff - 1541 dos
 * 09c000-09ffff - 1541 dos
 */


FlashAddonWidget::FlashAddonWidget( QWidget *parent )
: QWidget( parent )
, mpRemoveMe( new QPushButton( tr("Remove"), this ) )
, mpRomType( new QComboBox( this ) )
, mpRomName( new FileNameEdit( this ) )
, mpUploadToRam( new QPushButton( tr("Upload To RAM"), this ) )
{
   mpUploadToRam->setEnabled( false );
   QStringList romTypes;
   romTypes
         << "Disabled"
         << "Basic"
         << "Kernal"
         << "Charset"
         << "FC3"
         << "Replay"
         << "Floppy"
         << "MMC64"
         ;
   mpRomType->addItems( romTypes );
   QBoxLayout *layout = new QHBoxLayout( this );
   layout->setContentsMargins( 0, 0, 0, 0 );
   layout->addWidget( mpRemoveMe );
   layout->addWidget( mpRomType );
   layout->addWidget( mpRomName );
   layout->addWidget( mpUploadToRam );

   connect( mpRomType, SIGNAL(currentIndexChanged(int)),
            this, SLOT(handleRomTypeChange()) );
   connect( mpRemoveMe, SIGNAL(clicked()),
            this, SLOT(handleRemoveMe()) );
   connect( mpUploadToRam, SIGNAL(clicked()),
            this, SLOT(handleUploadToRam()) );

   setAcceptDrops( true );
}


FlashAddonWidget::~FlashAddonWidget()
{
}


void FlashAddonWidget::deactivate( bool deactivated )
{
   mpRemoveMe->setDisabled( deactivated );
   mpUploadToRam->setDisabled( deactivated || (mpRomType->currentIndex() < 1) );
}


void FlashAddonWidget::handleRomTypeChange()
{
   deactivate( !mpRemoveMe->isEnabled() );
   QString key;
   if( mpRomType->currentIndex() > 0 )
   {
      key = QString("Flash/%1").arg(typeName());
   }
   mpRomName->setRegistryKey( key );
}


void FlashAddonWidget::handleRemoveMe()
{
   emit requestRemoval( this );
}


void FlashAddonWidget::handleUploadToRam()
{
   emit requestUploadToRam( this );
}


void FlashAddonWidget::dragEnterEvent( QDragEnterEvent *event )
{
   if( event->mimeData()->hasFormat( "text/uri-list" ) )
   {
      event->acceptProposedAction();
   }
}


void FlashAddonWidget::dropEvent( QDropEvent *event )
{
   QList<QUrl> urls = event->mimeData()->urls();
   if( urls.isEmpty() )
   {
      return;
   }
   QString fileName = urls.first().toLocalFile();
   if( fileName.isEmpty() )
   {
      return;
   }
   mpRomName->setFileName( fileName );
}


void FlashAddonWidget::setFileName( const QString &name )
{
   mpRomName->setFileName( name );
}


QString FlashAddonWidget::fileName()
{
   return mpRomName->fileName();
}


FlashAddonWidget::ROMType FlashAddonWidget::type()
{
   return static_cast<ROMType>( mpRomType->currentIndex() );
}


void FlashAddonWidget::setType( FlashAddonWidget::ROMType type )
{
   mpRomType->setCurrentIndex( static_cast<int>(type) );
   mpRomName->setRegistryKey( QString("Flash/%1").arg(typeName()) );
}


QString FlashAddonWidget::typeName()
{
   return mpRomType->currentText();
}


bool FlashAddonWidget::setTypeByName( const QString &name )
{
   int index = mpRomType->findText( name );
   if( index >= 0 )
   {
      mpRomType->setCurrentIndex( index );
      mpRomName->setRegistryKey( QString("Flash/%1").arg(name) );
      return true;
   }
   else
   {
      return false;
   }
}


void FlashAddonWidget::addCurrentEntry()
{
   mpRomName->addCurrentEntry();
}
