/**
 * src/qchaco/FlashAddonWidget.hpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

#ifndef FLASHADDONWIDGET_HPP
#define FLASHADDONWIDGET_HPP FLASHADDONWIDGET_HPP

/* base class */
#include <QWidget>

/* system headers */

/* Qt headers */

/* local library headers */

/* local headers */

/* forward declaration of Qt classes */
class QComboBox;
class QPushButton;

/* forward declaration of local classes */
class FileNameEdit;


class FlashAddonWidget : public QWidget
{
Q_OBJECT

public:
   typedef enum {
      Disabled,
      Basic,
      Kernal,
      Charset,
      FC3,
      Replay,
      Floppy,
      MMC64
   } ROMType;

   FlashAddonWidget( QWidget *parent = 0 );
   virtual ~FlashAddonWidget();

   /* set the filename */
   void setFileName( const QString &name );
   /* get the filename */
   QString fileName();
   /* set the rom type */
   ROMType type();
   /* get the rom type  */
   void setType( ROMType type );
   /* get the rom type as string */
   QString typeName();
   /* set the rom type by string */
   bool setTypeByName( const QString &name );
   /* add current entry to history */
   void addCurrentEntry();

public slots:
   /* handle a change of the rom type selector */
   void handleRomTypeChange();
   /* handle the remove button */
   void handleRemoveMe();
   /* handle the upload button */
   void handleUploadToRam();
   /* deactivate the remove and upload buttons */
   void deactivate( bool deactivated );

signals:
   /* notify that the removal of this instance */
   void requestRemoval( FlashAddonWidget *widget );
   /* notify that that date should be uploaded */
   void requestUploadToRam( FlashAddonWidget *widget );

protected:
   /* handle drag'n'drop part one */
   void dragEnterEvent( QDragEnterEvent *event );
   /* handle drag'n'drop part two */
   void dropEvent( QDropEvent *event );

private:
   FlashAddonWidget( const FlashAddonWidget &other );
   FlashAddonWidget &operator=( const FlashAddonWidget &other );

   QPushButton    *mpRemoveMe;
   QComboBox      *mpRomType;
   FileNameEdit   *mpRomName;
   QPushButton    *mpUploadToRam;
};

#endif
