/**
 * src/qchaco/C64Widget.hpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

#ifndef FLASHWIDGET_HPP
#define FLASHWIDGET_HPP FLASHWIDGET_HPP

/* base class */
#include <QWidget>

/* system headers */

/* Qt headers */
#include <QList>

/* local library headers */

/* local headers */

/* forward declaration of Qt classes */
class QBoxLayout;
class QComboBox;
class QLabel;
class QPushButton;
class QString;

/* forward declaration of local classes */
class BaseSpinBox;
class FileNameEdit;
class FlashAddonWidget;

class FlashWidget : public QWidget
{
Q_OBJECT

public:
   FlashWidget( QWidget *parent = 0 );
   virtual ~FlashWidget();

public slots:
   /* add an addon */
   void addAddon();
   /* remove addon */
   void removeAddon( FlashAddonWidget* addon );
   /* upload addon to ROM */
   void uploadToRam( FlashAddonWidget* addon );
   /* start selected core */
   void start();
   /* flash selected core */
   void upload();
   /* deactivate the upload button */
   void deactivate( bool deactivated );

signals:
   /* request logging of a message */
   void log( const QString &msg );
   /* initiate chacocmd communication */
   void requestTransferStart();
   /* start core */
   void requestStart( int core );
   /* flash core */
   void requestFlash( int core, const QString rbfFile, const QByteArray &romData );
   /* send data for upload */
   void requestUpload( unsigned long addr, const QByteArray &data );
   /* send filename for upload */
   void requestUpload( unsigned long addr, const QString &data );

protected:

private:
   FlashWidget( const FlashWidget &other );
   FlashWidget &operator=( const FlashWidget &other );

   enum {
      BaseAddressBasic   = 0x00a000,
      BaseAddressKernal  = 0x00e000,
      BaseAddressCharset = 0x00d000,
      BaseAddressFinal3  = 0x010000,
      BaseAddressReplay  = 0x020000,
      BaseAddressFloppy1 = 0x088000,
      BaseAddressFloppy2 = 0x098000,
      BaseAddressMMC64   = 0x008000,
      BaseOffsetModule   = 0x100000
   };

   /* update the settings */
   void updateSettings();
   /* format the replaced... message */
   void replaceLog( unsigned long addr, unsigned long size,
                    const QString &type, const QString &fileName );

   FileNameEdit               *mpCoreFileName;
   FileNameEdit               *mpRomFileName;
   QComboBox                  *mpCore;
   QPushButton                *mpUpload;
   QPushButton                *mpAddAddon;
   QPushButton                *mpStartSlot;
   QBoxLayout                 *mpAddonsLayout;
   QList<FlashAddonWidget*>   mAdditionalRoms;
};

#endif
