/**
 * src/qchaco/HexEdit.cpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

/* class declaration */
#include "HexEdit.hpp"

/* system headers */

/* Qt headers */

/* local library headers */

/* local headers */
#include "HexEditValidator.hpp"


HexEdit::HexEdit( unsigned long maxValue, QWidget *parent )
: QLineEdit( parent )
{
   setValidator( new HexEditValidator( maxValue, this ) );
   int digits = 1;

   while( maxValue >>= 4 )
   {
      ++digits;
   }
   setMaxLength( digits );
   setText( QString( digits, '0' ) );
   //setInputMask( QString( digits, 'H' ) );

   QSize size( fontMetrics().size( Qt::TextSingleLine, text() ) );
   setFixedWidth( size.width() + height() - size.height() );
   connect( this, SIGNAL(textChanged(QString)),
            this, SLOT(handleValueChanged(QString)) );
}


HexEdit::~HexEdit()
{
}


void HexEdit::setValue( unsigned long value )
{
   setText( QString::number( value, 16 ).rightJustified( maxLength(), '0' ) );
}


unsigned long HexEdit::value()
{
   return text().toULong( 0, 16 );
}


void HexEdit::handleValueChanged( const QString &value )
{
   setText( value.toUpper() );
   emit valueChanged( value.toULong( 0, 16 ) );
}


void HexEdit::focusOutEvent( QFocusEvent *e )
{
   setText( text().rightJustified( maxLength(), '0' ) );
   QLineEdit::focusOutEvent( e );
}
