/**
 * src/qchaco/HistoryLineEdit.cpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

/* class declaration */
#include "HistoryLineEdit.hpp"

/* system headers */

/* Qt headers */
#include <QApplication>
#include <QLineEdit>
#include <QSettings>

/* local library headers */

/* local headers */


HistoryLineEdit::HistoryLineEdit( const QString &registryKey, QWidget *parent )
: QComboBox( parent )
, mMaxEntries( 50 )
, mRegistryKey( registryKey )
{
   setEditable( true );
   connect( lineEdit(), SIGNAL(returnPressed()),
            this, SIGNAL(returnPressed()) );
   setRegistryKey( registryKey );
}

HistoryLineEdit::HistoryLineEdit( QWidget *parent )
: QComboBox( parent )
, mMaxEntries( 50 )
, mRegistryKey()
{
   setEditable( true );
   connect( lineEdit(), SIGNAL(returnPressed()),
            this, SIGNAL(returnPressed()) );
   QSettings settings;
   settings.beginGroup( "HistoryLineEdit" );
   mMaxEntries = settings.value( "_MAX_ENTRIES_", 50 ).toInt();
}


HistoryLineEdit::~HistoryLineEdit()
{
}


void HistoryLineEdit::addEntry( const QString &entry )
{
   if( entry.isEmpty() )
   {
      return;
   }

   int index = findText( entry );
   if( index >= 0 )
   {
      removeItem( index );
   }
   insertItem( 0, entry );
   while( count() > mMaxEntries )
   {
      removeItem( count() - 1 );
   }

   if( !mRegistryKey.isEmpty() )
   {
      QSettings settings;
      settings.beginGroup( "History" );
      QStringList entries;
      for( int i = 0; i < count(); ++i )
      {
         entries.append( itemText( i ) );
      }
      settings.setValue( mRegistryKey, entries );
   }
}


void HistoryLineEdit::setHistorySize( int size )
{
   foreach( QWidget *widget, QApplication::topLevelWidgets() )
   {
      QList<HistoryLineEdit*> children( widget->findChildren<HistoryLineEdit*>() );
      foreach( HistoryLineEdit *child, children )
      {
         child->mMaxEntries = size;
      }
   }
}


QString HistoryLineEdit::registryKey() const
{
   return mRegistryKey;
}


void HistoryLineEdit::setRegistryKey( const QString &key )
{
   QSettings settings;
   settings.beginGroup( "HistoryLineEdit" );
   mMaxEntries = settings.value( "_MAX_ENTRIES_", 50 ).toInt();
   clear();
   mRegistryKey = key;
   if( !key.isEmpty() )
   {
      addItems( settings.value(key).toStringList() );
      while( count() > mMaxEntries )
      {
         removeItem( count() - 1 );
      }
   }
}
