/**
 * src/qchaco/HistoryList.cpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

/* class declaration */
#include "HistoryList.hpp"

/* system headers */

/* Qt headers */

/* local library headers */

/* local headers */


HistoryList::HistoryList( QWidget *parent )
: QListWidget( parent )
, mMaxEntries( 50 )
{
   setSelectionMode( QAbstractItemView::NoSelection );
   connect( this, SIGNAL(clicked(QModelIndex)),
            this, SLOT(handleClick(QModelIndex)) );
   setAlternatingRowColors( true );
}


HistoryList::~HistoryList()
{
}


void HistoryList::handleClick( const QModelIndex &index )
{
   emit entrySelected( itemFromIndex( index )->text() );
   clearSelection();
}


long HistoryList::maxEntries()
{
   return mMaxEntries;
}


QSize HistoryList::minimumSizeHint() const
{
   return QSize( 0, 0 );
}


void HistoryList::setMaxEntries( long maxEntries )
{
   mMaxEntries = maxEntries;
}


QStringList HistoryList::entries()
{
   QStringList list;

   for( int i = 0; i < count(); i++ )
   {
      list.append( item( i )->text() );
   }

   return list;
}


void HistoryList::setEntries( const QStringList &entries )
{
   clear();
   addItems( entries );
   while( count() > mMaxEntries )
   {
      delete takeItem( count() - 1 );
   }
}


void HistoryList::addEntry( const QString &value )
{
   foreach( QListWidgetItem* item, findItems( value, Qt::MatchExactly ) )
   {
      delete takeItem( row( item ) );
   }
   insertItem( 0, value );
   while( count() > mMaxEntries )
   {
      delete takeItem( count() - 1 );
   }
   clearSelection();
}
