/**
 * src/qchaco/PrgWidget.hpp
 * written by Sven Oliver Moll
 * 
 * distributed under the terms of the GNU Lesser General Public License (LGPL)
 * available at http://www.gnu.org/licenses/lgpl.html
 */

#ifndef C64WIDGET_HPP
#define C64WIDGET_HPP C64WIDGET_HPP

/* base class */
#include <QWidget>

/* system headers */

/* Qt headers */

/* local library headers */

/* local headers */

/* forward declaration of Qt classes */
class QCheckBox;
class QLabel;
class QPushButton;

/* forward declaration of local classes */
class BaseSpinBox;
class FileNameEdit;
class HexEdit;


class PrgWidget : public QWidget
{
Q_OBJECT

public:
   PrgWidget( QWidget *parent = 0 );
   virtual ~PrgWidget();

public slots:
   /* upload data */
   void upload();
   /* deactivate the upload button */
   void deactivate( bool deactivated );
   /* analyse the file for C64 compatibility */
   void analyse( const QString &fileName );
   /* update the widget configuration */
   void updateConfig();

signals:
   /* initiate chacocmd communication */
   void requestTransferStart();
   /* send data for upload */
   void requestUpload( unsigned long addr, const QByteArray &data );
   /* send filename for upload */
   void requestUpload( unsigned long addr, const QString &data );

protected:
   /* handle drag'n'drop part one */
   void dragEnterEvent( QDragEnterEvent *event );
   /* handle drag'n'drop part two */
   void dropEvent( QDropEvent *event );

private:
   PrgWidget( const PrgWidget &other );
   PrgWidget &operator=( const PrgWidget &other );

   FileNameEdit      *mpFileName;
   QCheckBox         *mpAutostart;
   QCheckBox         *mpTakeLoadAddress;
   QPushButton       *mpUpload;
   HexEdit           *mpStartAddress;
   HexEdit           *mpEndAddress;
   unsigned long     mDataSize;
};

#endif
