/*
 * grc.h - GCR handling.
 *
 * Written by
 *  Andreas Boose <viceteam@t-online.de>
 *  Daniel Sladic <sladic@eecg.toronto.edu>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 * PLEASE NOTE:
 * ============
 * This file has been modified since it has been copied from VICE.
 *
 */

#ifndef VICE_GCR_H
#define VICE_GCR_H

/* Number of bytes in one raw track.  */
#define NUM_MAX_BYTES_TRACK 8192

/* Number of tracks we emulate.  */
#define MAX_GCR_TRACKS 40

typedef struct gcr_s {
    /* Raw GCR image of the disk.  */
    unsigned char data[MAX_GCR_TRACKS * NUM_MAX_BYTES_TRACK];

    /* Speed zone image of the disk.  */
    unsigned char speed_zone[MAX_GCR_TRACKS * NUM_MAX_BYTES_TRACK];

    /* Size of the GCR data of each track.  */
    unsigned int track_size[MAX_GCR_TRACKS];

} gcr_t;

extern void gcr_convert_4bytes_to_GCR(unsigned char *source, unsigned char *dest);
extern void gcr_convert_GCR_to_4bytes(unsigned char *source, unsigned char *dest);

extern void gcr_convert_sector_to_GCR(unsigned char *buffer, unsigned char *ptr,
                                      unsigned int track, unsigned int sector,
                                      unsigned char diskID1, unsigned char diskID2,
                                      unsigned char error_code);
extern void gcr_convert_GCR_to_sector(unsigned char *buffer, unsigned char *ptr,
                                      unsigned char *GCR_track_start_ptr,
                                      unsigned int GCR_current_track_size);

extern unsigned char *gcr_find_sector_header(unsigned int track, unsigned int sector,
                                    unsigned char *gcr_track_start_ptr,
                                    unsigned int gcr_current_track_size);
extern unsigned char *gcr_find_sector_data(unsigned char *offset,
                                  unsigned char *gcr_track_start_ptr,
                                  unsigned int gcr_current_track_size);
extern int gcr_read_sector(unsigned char *gcr_track_start_ptr,
                           unsigned int gcr_current_track_size, unsigned char *readdata,
                           unsigned int track, unsigned int sector);
extern int gcr_write_sector(unsigned char *gcr_track_start_ptr,
                            unsigned int gcr_current_track_size,
                            unsigned char *writedata,
                            unsigned int track, unsigned int sector);

extern gcr_t *gcr_create_image(void);
extern void gcr_destroy_image(gcr_t *gcr);
#endif

